@@ -2,36 +2,26 @@
  * Copyright (C) 2018, Matthias Clasen
  * Copyright (C) 2019, Patrick Griffis
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This file is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, version 3.0 of the
+ * License.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: LGPL-3.0-only
  */
 
 #include "config.h"
 
 #include "background.h"
 #include "portal-private.h"
-#include "utils-private.h"
-
-/**
- * SECTION:background
- * @title: Background
- * @short_description: request background permissions
- *
- * These functions let the application request background permissions
- * such as enabling autostart.
- *
- * The underlying portal is org.freedesktop.portal.Background.
- */
 
 typedef struct {
   XdpPortal *portal;
@@ -54,7 +44,7 @@ background_call_free (BackgroundCall *call)
   if (call->parent)
     {
       call->parent->parent_unexport (call->parent);
-      _xdp_parent_free (call->parent);
+      xdp_parent_free (call->parent);
     }
   g_free (call->parent_handle);
   
@@ -216,19 +206,19 @@ request_background (BackgroundCall *call)
 
 /**
  * xdp_portal_request_background:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @parent: (nullable): parent window information
  * @commandline: (element-type utf8) (transfer container): command line to autostart
  * @reason: (nullable): reason to present to user for request
  * @flags: options for this call
- * @cancellable: (nullable): optional #GCancellable
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @user_data: (closure): data to pass to @callback
  *
  * Requests background permissions.
  *
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_request_background_finish() to get the results.
+ * call [method@Portal.request_background_finish] to get the results.
  */
 void
 xdp_portal_request_background (XdpPortal *portal,
@@ -249,7 +239,7 @@ xdp_portal_request_background (XdpPortal *portal,
   call = g_new0 (BackgroundCall, 1);
   call->portal = g_object_ref (portal);
   if (parent)
-    call->parent = _xdp_parent_copy (parent);
+    call->parent = xdp_parent_copy (parent);
   else
     call->parent_handle = g_strdup ("");
 
@@ -266,13 +256,13 @@ xdp_portal_request_background (XdpPortal *portal,
 
 /**
  * xdp_portal_request_background_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
- * Finishes the request, and returns %TRUE if successful.
+ * Finishes the request, and returns `TRUE` if successful.
  *
- * Returns: %TRUE if successful.
+ * Returns: `TRUE` if successful.
  */
 gboolean
 xdp_portal_request_background_finish (XdpPortal *portal,
