@@ -1,18 +1,20 @@
 /*
  * Copyright (C) 2018, Matthias Clasen
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This file is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, version 3.0 of the
+ * License.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: LGPL-3.0-only
  */
 
 #include "config.h"
@@ -27,21 +29,8 @@
 #include <gio/gunixfdlist.h>
 
 #include "portal-private.h"
-#include "utils-private.h"
 #include "email.h"
 
-/**
- * SECTION:email
- * @title: Email
- * @short_description: composing email messages
- *
- * These functions let applications send email, by prompting
- * the user to compose a message. The email may already have
- * an address, subject, body or attachments.
- *
- * The underlying portal is org.freedesktop.portal.Email.
- */
-
 #ifndef O_PATH
 #define O_PATH 0
 #endif
@@ -68,7 +57,7 @@ email_call_free (EmailCall *call)
   if (call->parent)
     {
       call->parent->parent_unexport (call->parent);
-      _xdp_parent_free (call->parent);
+      xdp_parent_free (call->parent);
     }
   g_free (call->parent_handle);
 
@@ -299,16 +288,16 @@ compose_email (EmailCall *call)
 
 /**
  * xdp_portal_compose_email:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @parent: (nullable): parent window information
- * @addresses: (nullable): the email addresses to send to
- * @cc: (nullable): the email addresses to cc
- * @bcc: (nullable): the email addresses to bcc
+ * @addresses: (array zero-terminated=1) (nullable): the email addresses to send to
+ * @cc: (array zero-terminated=1) (nullable): the email addresses to cc
+ * @bcc: (array zero-terminated=1) (nullable): the email addresses to bcc
  * @subject: (nullable): the subject for the email
  * @body: (nullable): the body for the email
- * @attachments: (nullable): an array of paths for files to attach
+ * @attachments: (array zero-terminated=1) (nullable): an array of paths for files to attach
  * @flags: options for this call
- * @cancellable: (nullable): optional #GCancellable
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  *
@@ -316,7 +305,7 @@ compose_email (EmailCall *call)
  * with some pre-filled information.
  *
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_compose_email_finish() to get the results.
+ * call [method@Portal.compose_email_finish] to get the results.
  */
 void
 xdp_portal_compose_email (XdpPortal *portal,
@@ -340,7 +329,7 @@ xdp_portal_compose_email (XdpPortal *portal,
   call = g_new0 (EmailCall, 1);
   call->portal = g_object_ref (portal);
   if (parent)
-    call->parent = _xdp_parent_copy (parent);
+    call->parent = xdp_parent_copy (parent);
   else
     call->parent_handle = g_strdup ("");
   call->addresses = g_strdupv ((char**)addresses);
@@ -357,13 +346,13 @@ xdp_portal_compose_email (XdpPortal *portal,
 
 /**
  * xdp_portal_compose_email_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
  * Finishes the compose-email request.
  *
- * Returns: %TRUE if the request was handled successfully
+ * Returns: `TRUE` if the request was handled successfully
  */
 gboolean
 xdp_portal_compose_email_finish (XdpPortal *portal,
