@@ -1,40 +1,26 @@
 /*
  * Copyright (C) 2018, Matthias Clasen
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This file is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, version 3.0 of the
+ * License.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: LGPL-3.0-only
  */
 
 #include "config.h"
 
 #include "filechooser.h"
 #include "portal-private.h"
-#include "utils-private.h"
-
-/**
- * SECTION:filechooser
- * @title: File
- * @short_description: access to files outside the sandbox
- *
- * These functions let applications ask the user for access to
- * files outside the sandbox, by presenting a file chooser dialog.
- *
- * The selected files will be made accessible to the application
- * via the document portal, and the returned URI will point
- * into the document portal fuse filesystem in /run/user/$UID/doc/.
- *
- * The underlying portal is org.freedesktop.portal.FileChooser.
- */
 
 typedef struct {
   XdpPortal *portal;
@@ -61,8 +47,8 @@ file_call_free (FileCall *call)
 {
   if (call->parent)
     {
-      call->parent->unexport (call->parent);
-      _xdp_parent_free (call->parent);
+      call->parent->parent_unexport (call->parent);
+      xdp_parent_free (call->parent);
     }
   g_free (call->parent_handle);
 
@@ -185,7 +171,7 @@ open_file (FileCall *call)
 
   if (call->parent_handle == NULL)
     {
-      call->parent->export (call->parent, parent_exported, call);
+      call->parent->parent_export (call->parent, parent_exported, call);
       return;
     }
 
@@ -221,9 +207,9 @@ open_file (FileCall *call)
   if (call->current_name)
     g_variant_builder_add (&options, "{sv}", "current_name", g_variant_new_string (call->current_name));
   if (call->current_folder)
-    g_variant_builder_add (&options, "{sv}", "current_folder", g_variant_new_string (call->current_folder));
+    g_variant_builder_add (&options, "{sv}", "current_folder", g_variant_new_bytestring (call->current_folder));
   if (call->current_file)
-    g_variant_builder_add (&options, "{sv}", "current_file", g_variant_new_string (call->current_file));
+    g_variant_builder_add (&options, "{sv}", "current_file", g_variant_new_bytestring (call->current_file));
 
   g_dbus_connection_call (call->portal->bus,
                           PORTAL_BUS_NAME,
@@ -241,14 +227,14 @@ open_file (FileCall *call)
 
 /**
  * xdp_portal_open_file:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @parent: (nullable): parent window information
  * @title: title for the file chooser dialog
- * @filters: (nullable): a #GVariant describing file filters
- * @current_filter: (nullable): a #GVariant describing the current file filter
- * @choices: (nullable): a #GVariant describing extra widgets
+ * @filters: (nullable): a [struct@GLib.Variant] describing file filters
+ * @current_filter: (nullable): a [struct@GLib.Variant] describing the current file filter
+ * @choices: (nullable): a [struct@GLib.Variant] describing extra widgets
  * @flags: options for this call
- * @cancellable: (nullable): optional #GCancellable
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  *
@@ -277,7 +263,7 @@ open_file (FileCall *call)
  * Example: [('encoding', 'Encoding', [('utf8', 'Unicode (UTF-8)'), ('latin15', 'Western')], 'latin15'), ('reencode', 'Reencode', [], 'false')]
  *
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_open_file_finish() to get the results.
+ * call [method@Portal.open_file_finish] to get the results.
  */
 void
 xdp_portal_open_file (XdpPortal *portal,
@@ -299,7 +285,7 @@ xdp_portal_open_file (XdpPortal *portal,
   call = g_new0 (FileCall, 1);
   call->portal = g_object_ref (portal);
   if (parent)
-    call->parent = _xdp_parent_copy (parent);
+    call->parent = xdp_parent_copy (parent);
   else
     call->parent_handle = g_strdup ("");
   call->method = "OpenFile";
@@ -316,19 +302,20 @@ xdp_portal_open_file (XdpPortal *portal,
 
 /**
  * xdp_portal_open_file_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
  * Finishes the open-file request, and returns
- * the result in the form of a #GVariant dictionary containing
+ * the result in the form of a [struct@GLib.Variant] dictionary containing
  * the following fields:
+ *
  * - uris `as`: an array of strings containing the uris of selected files
  * - choices `a(ss)`: an array of pairs of strings, the first string being the
  *     ID of a combobox that was passed into this call, the second string
  *     being the selected option.
  *
- * Returns: (transfer full): a #GVariant dictionary with the results
+ * Returns: (transfer full): a [struct@GLib.Variant] dictionary with the results
  */
 GVariant *
 xdp_portal_open_file_finish (XdpPortal *portal,
@@ -347,28 +334,28 @@ xdp_portal_open_file_finish (XdpPortal *portal,
 
 /**
  * xdp_portal_save_file:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @parent: (nullable): parent window information
  * @title: title for the file chooser dialog
  * @current_name: (nullable): suggested filename
  * @current_folder: (nullable): suggested folder to save the file in
  * @current_file: (nullable): the current file (when saving an existing file)
- * @filters: (nullable): a #GVariant describing file filters
- * @current_filter: (nullable): a #GVariant describing the current file filter
- * @choices: (nullable): a #GVariant describing extra widgets
+ * @filters: (nullable): a [struct@GLib.Variant] describing file filters
+ * @current_filter: (nullable): a [struct@GLib.Variant] describing the current file filter
+ * @choices: (nullable): a [struct@GLib.Variant] describing extra widgets
  * @flags: options for this call
- * @cancellable: (nullable): optional #GCancellable
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  *
  * Asks the user for a location to save a file.
  *
- * The format for the @filters argument is the same as for xdp_portal_open_file().
+ * The format for the @filters argument is the same as for [method@Portal.open_file].
 
- * The format for the @choices argument is the same as for xdp_portal_open_file().
+ * The format for the @choices argument is the same as for [method@Portal.open_file].
  *
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_save_file_finish() to get the results.
+ * call [method@Portal.save_file_finish] to get the results.
  */
 void
 xdp_portal_save_file (XdpPortal *portal,
@@ -393,7 +380,7 @@ xdp_portal_save_file (XdpPortal *portal,
   call = g_new0 (FileCall, 1);
   call->portal = g_object_ref (portal);
   if (parent)
-    call->parent = _xdp_parent_copy (parent);
+    call->parent = xdp_parent_copy (parent);
   else
     call->parent_handle = g_strdup ("");
   call->method = "SaveFile";
@@ -412,19 +399,20 @@ xdp_portal_save_file (XdpPortal *portal,
 
 /**
  * xdp_portal_save_file_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
  * Finishes the save-file request, and returns
- * the result in the form of a #GVariant dictionary containing
+ * the result in the form of a [struct@GLib.Variant] dictionary containing
  * the following fields:
+ *
  * - uris `(as)`: an array of strings containing the uri of the selected file
  * - choices `a(ss)`: an array of pairs of strings, the first string being the
  *   ID of a combobox that was passed into this call, the second string
  *   being the selected option.
  *
- * Returns: (transfer full): a #GVariant dictionary with the results
+ * Returns: (transfer full): a [struct@GLib.Variant] dictionary with the results
  */
 GVariant *
 xdp_portal_save_file_finish (XdpPortal *portal,
@@ -443,15 +431,15 @@ xdp_portal_save_file_finish (XdpPortal *portal,
 
 /**
  * xdp_portal_save_files:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @parent: (nullable): parent window information
  * @title: title for the file chooser dialog
  * @current_name: (nullable): suggested filename
  * @current_folder: (nullable): suggested folder to save the file in
  * @files: An array of file names to be saved
- * @choices: (nullable): a #GVariant describing extra widgets
+ * @choices: (nullable): a [struct@GLib.Variant] describing extra widgets
  * @flags: options for this call
- * @cancellable: (nullable): optional #GCancellable
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  *
@@ -462,10 +450,10 @@ xdp_portal_save_file_finish (XdpPortal *portal,
  * prompt or take some other action to construct a unique file name and
  * return that instead.
  *
- * The format for the @choices argument is the same as for xdp_portal_open_file().
+ * The format for the @choices argument is the same as for [method@Portal.open_file].
  *
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_save_file_finish() to get the results.
+ * call [method@Portal.save_file_finish] to get the results.
  */
 void
 xdp_portal_save_files (XdpPortal *portal,
@@ -489,7 +477,7 @@ xdp_portal_save_files (XdpPortal *portal,
   call = g_new0 (FileCall, 1);
   call->portal = g_object_ref (portal);
   if (parent)
-    call->parent = _xdp_parent_copy (parent);
+    call->parent = xdp_parent_copy (parent);
   else
     call->parent_handle = g_strdup ("");
   call->method = "SaveFiles";
@@ -506,13 +494,14 @@ xdp_portal_save_files (XdpPortal *portal,
 
 /**
  * xdp_portal_save_files_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
  * Finishes the save-files request, and returns
- * the result in the form of a #GVariant dictionary containing
+ * the result in the form of a [struct@GLib.Variant] dictionary containing
  * the following fields:
+ *
  * - uris `(as)`: an array of strings containing the uri corresponding to each
  *   file passed to the save-files request, in the same order. Note that the
  *   file names may have changed, for example if a file with the same name in
@@ -521,7 +510,7 @@ xdp_portal_save_files (XdpPortal *portal,
  *   ID of a combobox that was passed into this call, the second string
  *   being the selected option.
  *
- * Returns: (transfer full): a #GVariant dictionary with the results
+ * Returns: (transfer full): a [struct@GLib.Variant] dictionary with the results
  */
 GVariant *
 xdp_portal_save_files_finish (XdpPortal *portal,
