@@ -1,35 +1,26 @@
 /*
  * Copyright (C) 2018, Matthias Clasen
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This file is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, version 3.0 of the
+ * License.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: LGPL-3.0-only
  */
 
 #include "config.h"
 
 #include "print.h"
 #include "portal-private.h"
-#include "utils-private.h"
-
-/**
- * SECTION:print
- * @title: Print
- * @short_description: send documents to a printer
- *
- * These functions let applications print.
- *
- * The underlying portal is org.freedesktop.portal.Print.
- */
 
 #define GNU_SOURCE 1
 
@@ -66,7 +57,7 @@ print_call_free (PrintCall *call)
   if (call->parent)
     {
       call->parent->parent_unexport (call->parent);
-      _xdp_parent_free (call->parent);
+      xdp_parent_free (call->parent);
     }
   g_free (call->parent_handle);
 
@@ -272,20 +263,20 @@ do_print (PrintCall *call)
 
 /**
  * xdp_portal_prepare_print:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @parent: (nullable): parent window information
  * @title: tile for the print dialog
  * @settings: (nullable): Serialized print settings
  * @page_setup: (nullable): Serialized page setup
  * @flags: options for this call
- * @cancellable: (nullable): optional #GCancellable
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  * 
  * Presents a print dialog to the user and returns print settings and page setup.
  *
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_prepare_print_finish() to get the results.
+ * call [method@Portal.prepare_print_finish] to get the results.
  */
 void
 xdp_portal_prepare_print (XdpPortal *portal,
@@ -306,7 +297,7 @@ xdp_portal_prepare_print (XdpPortal *portal,
   call = g_new0 (PrintCall, 1);
   call->portal = g_object_ref (portal);
   if (parent)
-    call->parent = _xdp_parent_copy (parent);
+    call->parent = xdp_parent_copy (parent);
   else
     call->parent_handle = g_strdup ("");
   call->title = g_strdup (title);
@@ -321,18 +312,19 @@ xdp_portal_prepare_print (XdpPortal *portal,
 
 /**
  * xdp_portal_prepare_print_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
- * Finishes the prepare-print request, and returns #GVariant dictionary
+ * Finishes the prepare-print request, and returns [struct@GLib.Variant] dictionary
  * with the following information:
+ *
  * - settings `a{sv}`: print settings as set up by the user in the print dialog
  * - page-setup `a{sv}: page setup as set up by the user in the print dialog
- * - token u: a token that can by used in a xdp_portal_print_file() call to
+ * - token u: a token that can by used in a [method@Portal.print_file] call to
  *     avoid the print dialog
  *
- * Returns: (transfer full): a #GVariant dictionary with print information
+ * Returns: (transfer full): a [struct@GLib.Variant] dictionary with print information
  */
 GVariant *
 xdp_portal_prepare_print_finish (XdpPortal *portal,
@@ -348,13 +340,13 @@ xdp_portal_prepare_print_finish (XdpPortal *portal,
 
 /**
  * xdp_portal_print_file:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @parent: (nullable): parent window information
  * @title: tile for the print dialog
- * @token: token that was returned by a previous xdp_portal_prepare_print() call, or 0
+ * @token: token that was returned by a previous [method@Portal.prepare_print] call, or 0
  * @file: path of the document to print
  * @flags: options for this call
- * @cancellable: (nullable): optional #GCancellable
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  * 
@@ -365,7 +357,7 @@ xdp_portal_prepare_print_finish (XdpPortal *portal,
  * no token is present, then a print dialog will be presented to the user.
  *
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_print_file_finish() to get the results.
+ * call [method@Portal.print_file_finish] to get the results.
  */
 void
 xdp_portal_print_file (XdpPortal *portal,
@@ -386,7 +378,7 @@ xdp_portal_print_file (XdpPortal *portal,
   call = g_new0 (PrintCall, 1);
   call->portal = g_object_ref (portal);
   if (parent)
-    call->parent = _xdp_parent_copy (parent);
+    call->parent = xdp_parent_copy (parent);
   else
     call->parent_handle = g_strdup ("");
   call->title = g_strdup (title);
@@ -401,13 +393,13 @@ xdp_portal_print_file (XdpPortal *portal,
 
 /**
  * xdp_portal_print_file_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
  * Finishes the print request.
  *
- * Returns: %TRUE if the request was successful
+ * Returns: `TRUE` if the request was successful
  */
 gboolean
 xdp_portal_print_file_finish (XdpPortal *portal,
