@@ -1,18 +1,20 @@
 /*
  * Copyright (C) 2018, Matthias Clasen
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This file is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, version 3.0 of the
+ * License.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: LGPL-3.0-only
  */
 
 #include "config.h"
@@ -22,28 +24,6 @@
 #include "remote.h"
 #include "portal-private.h"
 #include "session-private.h"
-#include "utils-private.h"
-
-/**
- * SECTION:screencast
- * @title: Screencast
- * @short_description: create screencast sessions
- *
- * A screencast session makes the content of a monitor or window
- * available as a pipewire stream.
- *
- * The underlying portal is org.freedesktop.portal.ScreenCast.
- */
-
-/**
- * SECTION:remote
- * @title: Remote desktop
- * @short_description: allow remote control of the session
- *
- * A remote desktop session allows to inject events into the input stream.
- *
- * The underlying portal is org.freedesktop.portal.RemoteDesktop.
- */
 
 typedef struct {
   XdpPortal *portal;
@@ -51,6 +31,9 @@ typedef struct {
   XdpSessionType type;
   XdpDeviceType devices;
   XdpOutputType outputs;
+  XdpCursorMode cursor_mode;
+  XdpPersistMode persist_mode;
+  char *restore_token;
   gboolean multiple;
   guint signal_id;
   GTask *task;
@@ -68,6 +51,7 @@ create_call_free (CreateCall *call)
     g_signal_handler_disconnect (g_task_get_cancellable (call->task), call->cancelled_id);
 
   g_free (call->request_path);
+  g_free (call->restore_token);
 
   g_object_unref (call->portal);
   g_object_unref (call->task);
@@ -100,9 +84,9 @@ sources_selected (GDBusConnection *bus,
        g_task_return_pointer (call->task, session, g_object_unref);
     }
   else if (response == 1)
-    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_CANCELLED, "Remote desktop canceled");
+    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_CANCELLED, "Screencast SelectSources() canceled");
   else if (response == 2)
-    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_FAILED, "Remote desktop failed");
+    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_FAILED, "Screencast SelectSources() failed");
 
   create_call_free (call);
 }
@@ -148,6 +132,13 @@ select_sources (CreateCall *call)
   g_variant_builder_add (&options, "{sv}", "handle_token", g_variant_new_string (token));
   g_variant_builder_add (&options, "{sv}", "types", g_variant_new_uint32 (call->outputs));
   g_variant_builder_add (&options, "{sv}", "multiple", g_variant_new_boolean (call->multiple));
+  g_variant_builder_add (&options, "{sv}", "cursor_mode", g_variant_new_uint32 (call->cursor_mode));
+  if (call->portal->screencast_interface_version >= 4)
+    {
+      g_variant_builder_add (&options, "{sv}", "persist_mode", g_variant_new_uint32 (call->persist_mode));
+      if (call->restore_token)
+        g_variant_builder_add (&options, "{sv}", "restore_token", g_variant_new_string (call->restore_token));
+    }
   g_dbus_connection_call (call->portal->bus,
                           PORTAL_BUS_NAME,
                           PORTAL_OBJECT_PATH,
@@ -191,9 +182,9 @@ devices_selected (GDBusConnection *bus,
        }
     }
   else if (response == 1)
-    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_CANCELLED, "Remote desktop canceled");
+    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_CANCELLED, "Remote desktop SelectDevices() canceled");
   else if (response == 2)
-    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_FAILED, "Remote desktop failed");
+    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_FAILED, "Remote desktop SelectDevices() failed");
 
   if (response != 0)
     create_call_free (call);
@@ -221,7 +212,7 @@ select_devices (CreateCall *call)
 
   g_variant_builder_init (&options, G_VARIANT_TYPE_VARDICT);
   g_variant_builder_add (&options, "{sv}", "handle_token", g_variant_new_string (token));
-  g_variant_builder_add (&options, "{sv}", "type", g_variant_new_uint32 (call->devices));
+  g_variant_builder_add (&options, "{sv}", "types", g_variant_new_uint32 (call->devices));
   g_dbus_connection_call (call->portal->bus,
                           PORTAL_BUS_NAME,
                           PORTAL_OBJECT_PATH,
@@ -335,24 +326,71 @@ create_session (CreateCall *call)
                           call);
 }
 
+static void
+get_version_returned (GObject *object,
+                      GAsyncResult *result,
+                      gpointer data)
+{
+  CreateCall *call = data;
+  GError *error = NULL;
+  g_autoptr(GVariant) version_variant = NULL;
+  g_autoptr(GVariant) ret = NULL;
+
+  ret = g_dbus_connection_call_finish (G_DBUS_CONNECTION (object), result, &error);
+  if (error)
+    {
+      g_task_return_error (call->task, error);
+      create_call_free (call);
+      return;
+    }
+
+  g_variant_get_child (ret, 0, "v", &version_variant);
+  call->portal->screencast_interface_version = g_variant_get_uint32 (version_variant);
+
+  create_session (call);
+}
+
+static void
+get_screencast_interface_version (CreateCall *call)
+{
+  g_dbus_connection_call (call->portal->bus,
+                          PORTAL_BUS_NAME,
+                          PORTAL_OBJECT_PATH,
+                          "org.freedesktop.DBus.Properties",
+                          "Get",
+                          g_variant_new ("(ss)", "org.freedesktop.portal.ScreenCast", "version"),
+                          NULL,
+                          G_DBUS_CALL_FLAGS_NONE,
+                          -1,
+                          g_task_get_cancellable (call->task),
+                          get_version_returned,
+                          call);
+}
+
 /**
  * xdp_portal_create_screencast_session:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @outputs: which kinds of source to offer in the dialog
  * @flags: options for this call
- * @cancellable: (nullable): optional #GCancellable
+ * @cursor_mode: the cursor mode of the session
+ * @persist_mode: the persist mode of the session
+ * @restore_token: (nullable): the token of a previous screencast session to restore
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  *
  * Creates a session for a screencast.
  *
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_create_screencast_session_finish() to get the results.
+ * call [method@Portal.create_screencast_session_finish] to get the results.
  */
 void
 xdp_portal_create_screencast_session (XdpPortal *portal,
                                       XdpOutputType outputs,
                                       XdpScreencastFlags flags,
+                                      XdpCursorMode cursor_mode,
+                                      XdpPersistMode persist_mode,
+                                      const char *restore_token,
                                       GCancellable *cancellable,
                                       GAsyncReadyCallback  callback,
                                       gpointer data)
@@ -367,21 +405,27 @@ xdp_portal_create_screencast_session (XdpPortal *portal,
   call->type = XDP_SESSION_SCREENCAST;
   call->devices = XDP_DEVICE_NONE;
   call->outputs = outputs;
+  call->cursor_mode = cursor_mode;
+  call->persist_mode = persist_mode;
+  call->restore_token = g_strdup (restore_token);
   call->multiple = (flags & XDP_SCREENCAST_FLAG_MULTIPLE) != 0;
   call->task = g_task_new (portal, cancellable, callback, data);
 
-  create_session (call);
+  if (portal->screencast_interface_version == 0)
+    get_screencast_interface_version (call);
+  else
+    create_session (call);
 }
 
 /**
  * xdp_portal_create_screencast_session_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
- * Finishes the create-screencast request, and returns an #XdpSession.
+ * Finishes the create-screencast request, and returns an [class@Session].
  *
- * Returns: (transfer full): a #XdpSession
+ * Returns: (transfer full): a [class@Session]
  */
 XdpSession *
 xdp_portal_create_screencast_session_finish (XdpPortal *portal,
@@ -402,24 +446,26 @@ xdp_portal_create_screencast_session_finish (XdpPortal *portal,
 
 /**
  * xdp_portal_create_remote_desktop_session:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @devices: which kinds of input devices to ofer in the new dialog
  * @outputs: which kinds of source to offer in the dialog
  * @flags: options for this call
- * @cancellable: (nullable): optional #GCancellable
+ * @cursor_mode: the cursor mode of the session
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  *
  * Creates a session for remote desktop.
  *
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_create_remote_desktop_session_finish() to get the results.
+ * call [method@Portal.create_remote_desktop_session_finish] to get the results.
  */
 void
 xdp_portal_create_remote_desktop_session (XdpPortal *portal,
                                           XdpDeviceType devices,
                                           XdpOutputType outputs,
                                           XdpRemoteDesktopFlags flags,
+                                          XdpCursorMode cursor_mode,
                                           GCancellable *cancellable,
                                           GAsyncReadyCallback  callback,
                                           gpointer data)
@@ -434,6 +480,9 @@ xdp_portal_create_remote_desktop_session (XdpPortal *portal,
   call->type = XDP_SESSION_REMOTE_DESKTOP;
   call->devices = devices;
   call->outputs = outputs;
+  call->cursor_mode = cursor_mode;
+  call->persist_mode = XDP_PERSIST_MODE_NONE;
+  call->restore_token = NULL;
   call->multiple = (flags & XDP_REMOTE_DESKTOP_FLAG_MULTIPLE) != 0;
   call->task = g_task_new (portal, cancellable, callback, data);
 
@@ -442,13 +491,13 @@ xdp_portal_create_remote_desktop_session (XdpPortal *portal,
 
 /**
  * xdp_portal_create_remote_desktop_session_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
- * Finishes the create-remote-desktop request, and returns an #XdpSession.
+ * Finishes the create-remote-desktop request, and returns an [class@Session].
  *
- * Returns: (transfer full): a #XdpSession
+ * Returns: (transfer full): a [class@Session]
  */
 XdpSession *
 xdp_portal_create_remote_desktop_session_finish (XdpPortal *portal,
@@ -485,11 +534,11 @@ start_call_free (StartCall *call)
 {
   if (call->parent)
     {
-      call->parent->unexport (call->parent);
-      _xdp_parent_free (call->parent);
+      call->parent->parent_unexport (call->parent);
+      xdp_parent_free (call->parent);
     }
   g_free (call->parent_handle);
-  
+
   if (call->signal_id)
     g_dbus_connection_signal_unsubscribe (call->portal->bus, call->signal_id);
 
@@ -522,12 +571,16 @@ session_started (GDBusConnection *bus,
 
   _xdp_session_set_session_state (call->session, response == 0 ? XDP_SESSION_ACTIVE
                                                                : XDP_SESSION_CLOSED);
- 
+
   if (response == 0)
     {
       guint32 devices;
       GVariant *streams;
 
+      if (!g_variant_lookup (ret, "persist_mode", "u", &call->session->persist_mode))
+        call->session->persist_mode = XDP_PERSIST_MODE_NONE;
+      if (!g_variant_lookup (ret, "restore_token", "s", &call->session->restore_token))
+        call->session->restore_token = NULL;
       if (g_variant_lookup (ret, "devices", "u", &devices))
         _xdp_session_set_devices (call->session, devices);
       if (g_variant_lookup (ret, "streams", "@a(ua{sv})", &streams))
@@ -536,9 +589,13 @@ session_started (GDBusConnection *bus,
       g_task_return_boolean (call->task, TRUE);
     }
   else if (response == 1)
-    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_CANCELLED, "Screencast canceled");
+    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_CANCELLED,
+                             call->session->type == XDP_SESSION_REMOTE_DESKTOP ?
+                             "Remote desktop canceled" : "Screencast canceled");
   else if (response == 2)
-    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_FAILED, "Screencast failed");
+    g_task_return_new_error (call->task, G_IO_ERROR, G_IO_ERROR_FAILED,
+                             call->session->type == XDP_SESSION_REMOTE_DESKTOP ?
+                             "Remote desktop failed" : "Screencast failed");
 
   start_call_free (call);
 }
@@ -582,7 +639,7 @@ start_session (StartCall *call)
 
   if (call->parent_handle == NULL)
     {
-      call->parent->export (call->parent, parent_exported, call);
+      call->parent->parent_export (call->parent, parent_exported, call);
       return;
     }
 
@@ -626,17 +683,17 @@ start_session (StartCall *call)
 
 /**
  * xdp_session_start:
- * @session: a #XdpSession in initial state
+ * @session: a [class@Session] in initial state
  * @parent: (nullable): parent window information
- * @cancellable: (nullable): optional #GCancellable
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  *
  * Starts the session.
- * 
+ *
  * When the request is done, @callback will be called. You can then
- * call xdp_session_start_finish() to get the results.
- */ 
+ * call [method@Session.start_finish] to get the results.
+ */
 void
 xdp_session_start (XdpSession *session,
                    XdpParent *parent,
@@ -652,7 +709,7 @@ xdp_session_start (XdpSession *session,
   call->portal = g_object_ref (session->portal);
   call->session = g_object_ref (session);
   if (parent)
-    call->parent = _xdp_parent_copy (parent);
+    call->parent = xdp_parent_copy (parent);
   else
     call->parent_handle = g_strdup ("");
   call->task = g_task_new (session, cancellable, callback, data);
@@ -662,13 +719,13 @@ xdp_session_start (XdpSession *session,
 
 /**
  * xdp_session_start_finish:
- * @session: a #XdpSession
- * @result: a #GAsyncResult
+ * @session: a [class@Session]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
  * Finishes the session-start request.
  *
- * Returns: %TRUE if the session was started successfully.
+ * Returns: `TRUE` if the session was started successfully.
  */
 gboolean
 xdp_session_start_finish (XdpSession *session,
@@ -683,7 +740,7 @@ xdp_session_start_finish (XdpSession *session,
 
 /**
  * xdp_session_close:
- * @session: an active #XdpSession
+ * @session: an active [class@Session]
  *
  * Closes the session.
  */
@@ -706,14 +763,14 @@ xdp_session_close (XdpSession *session)
 
 /**
  * xdp_session_open_pipewire_remote:
- * @session: a #XdpSession
+ * @session: a [class@Session]
  *
  * Opens a file descriptor to the pipewire remote where the screencast
  * streams are available. The file descriptor should be used to create
  * a pw_remote object, by using pw_remote_connect_fd(). Only the
  * screencast stream nodes will be available from this pipewire node.
  *
- * Returns: the file ddescriptor
+ * Returns: the file descriptor
  */
 int
 xdp_session_open_pipewire_remote (XdpSession *session)
@@ -753,14 +810,14 @@ xdp_session_open_pipewire_remote (XdpSession *session)
 
 /**
  * xdp_session_pointer_motion:
- * @session: a #XdpSession
+ * @session: a [class@Session]
  * @dx: relative horizontal movement
  * @dy: relative vertical movement
  *
  * Moves the pointer from its current position.
- * 
+ *
  * May only be called on a remote desktop session
- * with %XDP_DEVICE_POINTER access.
+ * with `XDP_DEVICE_POINTER` access.
  */
 void
 xdp_session_pointer_motion (XdpSession *session,
@@ -786,7 +843,7 @@ xdp_session_pointer_motion (XdpSession *session,
 
 /**
  * xdp_session_pointer_position:
- * @session: a #XdpSession
+ * @session: a [class@Session]
  * @stream: the node ID of the pipewire stream the position is relative to
  * @x: new X position
  * @y: new Y position
@@ -795,7 +852,7 @@ xdp_session_pointer_motion (XdpSession *session,
  * coordinate space.
  * 
  * May only be called on a remote desktop session
- * with %XDP_DEVICE_POINTER access.
+ * with `XDP_DEVICE_POINTER` access.
  */
 void
 xdp_session_pointer_position (XdpSession *session,
@@ -822,14 +879,14 @@ xdp_session_pointer_position (XdpSession *session,
 
 /**
  * xdp_session_pointer_button:
- * @session: a #XdpSession
+ * @session: a [class@Session]
  * @button: the button
  * @state: the new state
  *
  * Changes the state of the button to @state.
- * 
+ *
  * May only be called on a remote desktop session
- * with %XDP_DEVICE_POINTER access.
+ * with `XDP_DEVICE_POINTER` access.
  */
 void
 xdp_session_pointer_button (XdpSession *session,
@@ -855,7 +912,7 @@ xdp_session_pointer_button (XdpSession *session,
 
 /**
  * xdp_session_pointer_axis:
- * @session: a #XdpSession
+ * @session: a [class@Session]
  * @finish: whether this is the last in a series of related events
  * @dx: relative axis movement on the X axis
  * @dy: relative axis movement on the Y axis
@@ -865,7 +922,7 @@ xdp_session_pointer_button (XdpSession *session,
  * the motion vector of a pointer motion done using the same advice.
  *
  * May only be called on a remote desktop session
- * with %XDP_DEVICE_POINTER access.
+ * with `XDP_DEVICE_POINTER` access.
  */
 void
 xdp_session_pointer_axis (XdpSession *session,
@@ -893,14 +950,14 @@ xdp_session_pointer_axis (XdpSession *session,
 
 /**
  * xdp_session_pointer_axis_discrete:
- * @session: a #XdpSession
+ * @session: a [class@Session]
  * @axis: the axis to change
  * @steps: number of steps scrolled
  *
  * The axis movement from a discrete scroll device.
  *
  * May only be called on a remote desktop session
- * with %XDP_DEVICE_POINTER access.
+ * with `XDP_DEVICE_POINTER` access.
  */
 void
 xdp_session_pointer_axis_discrete (XdpSession *session,
@@ -926,15 +983,15 @@ xdp_session_pointer_axis_discrete (XdpSession *session,
 
 /**
  * xdp_session_keyboard_key:
- * @session: a remote desktop #XdpSession
+ * @session: a remote desktop [class@Session]
  * @keysym: whether to interpret @key as a keysym instead of a keycode
  * @key: the keysym or keycode to change
  * @state: the new state
- * 
+ *
  * Changes the state of the key to @state.
  *
  * May only be called on a remote desktop session
- * with %XDP_DEVICE_KEYBOARD access.
+ * with `XDP_DEVICE_KEYBOARD` access.
  */
 void
 xdp_session_keyboard_key (XdpSession *session,
@@ -961,18 +1018,18 @@ xdp_session_keyboard_key (XdpSession *session,
 
 /**
  * xdp_session_touch_down:
- * @session: a #XdpSession
+ * @session: a [class@Session]
  * @stream: the node ID of the pipewire stream the position is relative to
  * @slot: touch slot where the touch point appeared
  * @x: new X position
  * @y: new Y position
  *
- * Notify about a new touch down event. The (x, y) position
+ * Notify about a new touch down event. The `(x, y)` position
  * represents the new touch point position in the streams logical
  * coordinate space.
  *
  * May only be called on a remote desktop session
- * with %XDP_DEVICE_TOUCHSCREEN access.
+ * with `XDP_DEVICE_TOUCHSCREEN` access.
  */
 void
 xdp_session_touch_down (XdpSession *session,
@@ -1000,18 +1057,18 @@ xdp_session_touch_down (XdpSession *session,
 
 /**
  * xdp_session_touch_position:
- * @session: a #XdpSession
+ * @session: a [class@Session]
  * @stream: the node ID of the pipewire stream the position is relative to
  * @slot: touch slot that is changing position
  * @x: new X position
  * @y: new Y position
  *
- * Notify about a new touch motion event. The (x, y) position
+ * Notify about a new touch motion event. The `(x, y)` position
  * represents where the touch point position in the streams logical
  * coordinate space moved.
  *
  * May only be called on a remote desktop session
- * with %XDP_DEVICE_TOUCHSCREEN access.
+ * with `XDP_DEVICE_TOUCHSCREEN` access.
  */
 void
 xdp_session_touch_position (XdpSession *session,
@@ -1039,13 +1096,13 @@ xdp_session_touch_position (XdpSession *session,
 
 /**
  * xdp_session_touch_up:
- * @session: a #XdpSession
+ * @session: a [class@Session]
  * @slot: touch slot that changed
  *
  * Notify about a new touch up event.
  *
  * May only be called on a remote desktop session
- * with %XDP_DEVICE_TOUCHSCREEN access.
+ * with `XDP_DEVICE_TOUCHSCREEN` access.
  */
 void
 xdp_session_touch_up (XdpSession *session,
@@ -1067,3 +1124,49 @@ xdp_session_touch_up (XdpSession *session,
                           g_variant_new ("(oa{sv}u)", session->id, &options, slot),
                           NULL, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL, NULL);
 }
+
+/**
+ * xdp_session_get_persist_mode:
+ * @session: a [class@Session]
+ *
+ * Retrieves the effective persist mode of @session.
+ *
+ * May only be called after @session is successfully started, i.e. after
+ * [method@Session.start_finish].
+ *
+ * Returns: the effective persist mode of @session
+ */
+XdpPersistMode
+xdp_session_get_persist_mode (XdpSession *session)
+{
+  g_return_val_if_fail (XDP_IS_SESSION (session), XDP_PERSIST_MODE_NONE);
+  g_return_val_if_fail (session->state == XDP_SESSION_ACTIVE, XDP_PERSIST_MODE_NONE);
+
+  return session->persist_mode;
+}
+
+/**
+ * xdp_session_get_restore_token:
+ * @session: a [class@Session]
+ *
+ * Retrieves the restore token of @session.
+ *
+ * A restore token will only be available if `XDP_PERSIST_MODE_TRANSIENT`
+ * or `XDP_PERSIST_MODE_PERSISTENT` was passed when creating the screencast
+ * session.
+ *
+ * Remote desktop sessions cannot be restored.
+ *
+ * May only be called after @session is successfully started, i.e. after
+ * [method@Session.start_finish].
+ *
+ * Returns: (nullable): the restore token of @session
+ */
+char *
+xdp_session_get_restore_token (XdpSession *session)
+{
+  g_return_val_if_fail (XDP_IS_SESSION (session), NULL);
+  g_return_val_if_fail (session->state == XDP_SESSION_ACTIVE, NULL);
+
+  return g_strdup (session->restore_token);
+}
