@@ -1,35 +1,26 @@
 /*
  * Copyright (C) 2018, Matthias Clasen
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This file is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, version 3.0 of the
+ * License.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: LGPL-3.0-only
  */
 
 #include "config.h"
 
 #include "screenshot.h"
 #include "portal-private.h"
-#include "utils-private.h"
-
-/**
- * SECTION:screenshot
- * @title: Screenshot
- * @short_description: take a screenshot
- *
- * These functions let the application take a screenshot or pick a color.
- * 
- * The underlying portal is org.freedesktop.portal.Screenshot.
- */
 
 typedef struct {
   XdpPortal *portal;
@@ -49,7 +40,7 @@ screenshot_call_free (ScreenshotCall *call)
   if (call->parent)
     {
       call->parent->parent_unexport (call->parent);
-      _xdp_parent_free (call->parent);
+      xdp_parent_free (call->parent);
     }
   g_free (call->parent_handle);
   
@@ -219,17 +210,17 @@ take_screenshot (ScreenshotCall *call)
 
 /**
  * xdp_portal_take_screenshot:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @parent: (nullable): parent window information
  * @flags: options for this call
- * @cancellable: (nullable): optional #GCancellable
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  *
  * Takes a screenshot.
  * 
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_take_screenshot_finish() to get the results.
+ * call [method@Portal.take_screenshot_finish] to get the results.
  */
 void
 xdp_portal_take_screenshot (XdpPortal *portal,
@@ -248,7 +239,7 @@ xdp_portal_take_screenshot (XdpPortal *portal,
   call->color = FALSE;
   call->portal = g_object_ref (portal);
   if (parent)
-    call->parent = _xdp_parent_copy (parent);
+    call->parent = xdp_parent_copy (parent);
   else
     call->parent_handle = g_strdup ("");
   call->interactive = (flags & XDP_SCREENSHOT_FLAG_INTERACTIVE) != 0;
@@ -260,8 +251,8 @@ xdp_portal_take_screenshot (XdpPortal *portal,
 
 /**
  * xdp_portal_take_screenshot_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
  * Finishes a screenshot request, and returns
@@ -283,16 +274,16 @@ xdp_portal_take_screenshot_finish (XdpPortal *portal,
 
 /**
  * xdp_portal_pick_color:
- * @portal: a #XdpPortal
+ * @portal: a [class@Portal]
  * @parent: (nullable): parent window information
- * @cancellable: (nullable): optional #GCancellable
+ * @cancellable: (nullable): optional [class@Gio.Cancellable]
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  *
  * Lets the user pick a color from the screen.
  * 
  * When the request is done, @callback will be called. You can then
- * call xdp_portal_pick_color_finish() to get the results.
+ * call [method@Portal.pick_color_finish] to get the results.
  */
 void
 xdp_portal_pick_color (XdpPortal *portal,
@@ -309,7 +300,7 @@ xdp_portal_pick_color (XdpPortal *portal,
   call->color = TRUE;
   call->portal = g_object_ref (portal);
   if (parent)
-    call->parent = _xdp_parent_copy (parent);
+    call->parent = xdp_parent_copy (parent);
   else
     call->parent_handle = g_strdup ("");
   call->task = g_task_new (portal, cancellable, callback, data);
@@ -320,8 +311,8 @@ xdp_portal_pick_color (XdpPortal *portal,
 
 /**
  * xdp_portal_pick_color_finish:
- * @portal: a #XdpPortal
- * @result: a #GAsyncResult
+ * @portal: a [class@Portal]
+ * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
  * Finishes a pick-color request, and returns
